@@ -120,11 +120,14 @@ PYTHON_CONFIG = {
                     'args': []
                 },
                 'flake8': {
-                     'enabled': False,
+                    'enabled': False,
                 },
                 'pyls_spyder': {
                     'enable_block_comments': True,
                     'group_cells': True
+                },
+                'pyls_flake8': {
+                    'enabled': False,
                 }
             },
 
