@@ -22,10 +22,6 @@ from spyder.py3compat import PY2
 
 class IPythonConsoleConfigPage(PluginConfigPage):
 
-    def __init__(self, plugin, parent):
-        PluginConfigPage.__init__(self, plugin, parent)
-        self.get_name = lambda: _("IPython console")
-
     def setup_page(self):
         newcb = self.create_checkbox
 
@@ -35,13 +31,6 @@ class IPythonConsoleConfigPage(PluginConfigPage):
                            tip=_("This option lets you hide the message "
                                  "shown at\nthe top of the console when "
                                  "it's opened."))
-        pager_box = newcb(_("Use a pager to display additional text inside "
-                            "the console"), 'use_pager',
-                          tip=_("Useful if you don't want to fill the "
-                                "console with long help or completion "
-                                "texts.\n"
-                                "Note: Use the Q key to get out of the "
-                                "pager."))
         calltips_box = newcb(_("Show calltips"), 'show_calltips')
         ask_box = newcb(_("Ask for confirmation before closing"),
                         'ask_before_closing')
@@ -60,7 +49,6 @@ class IPythonConsoleConfigPage(PluginConfigPage):
 
         interface_layout = QVBoxLayout()
         interface_layout.addWidget(banner_box)
-        interface_layout.addWidget(pager_box)
         interface_layout.addWidget(calltips_box)
         interface_layout.addWidget(ask_box)
         interface_layout.addWidget(reset_namespace_box)
@@ -122,16 +110,10 @@ class IPythonConsoleConfigPage(PluginConfigPage):
                               "separate window.") % (inline, automatic))
         bend_label.setWordWrap(True)
 
-        backends = [(inline, 0), (automatic, 1), ("Qt5", 2), ("Qt4", 3)]
+        backends = [(inline, 0), (automatic, 1), ("Qt5", 2), ("Tkinter", 3)]
 
         if sys.platform == 'darwin':
-            backends.append(("OS X", 4))
-        if sys.platform.startswith('linux'):
-            backends.append(("Gtk3", 5))
-            backends.append(("Gtk", 6))
-        if PY2:
-            backends.append(("Wx", 7))
-        backends.append(("Tkinter", 8))
+            backends.append(("macOS", 4))
         backends = tuple(backends)
 
         backend_box = self.create_combobox(
@@ -220,23 +202,6 @@ class IPythonConsoleConfigPage(PluginConfigPage):
         run_lines_layout.addWidget(run_lines_edit)
         run_lines_group.setLayout(run_lines_layout)
 
-        # Pdb run lines Group
-        pdb_run_lines_group = QGroupBox(_("Run code while debugging"))
-        pdb_run_lines_label = QLabel(_(
-            "You can run several lines of code on each "
-            "new prompt while debugging. Please "
-            "introduce each one separated by semicolons "
-            "and a space, for example:<br>"
-            "<i>import matplotlib.pyplot as plt</i>"))
-        pdb_run_lines_label.setWordWrap(True)
-        pdb_run_lines_edit = self.create_lineedit(
-            _("Lines:"), 'startup/pdb_run_lines', '', alignment=Qt.Horizontal)
-
-        pdb_run_lines_layout = QVBoxLayout()
-        pdb_run_lines_layout.addWidget(pdb_run_lines_label)
-        pdb_run_lines_layout.addWidget(pdb_run_lines_edit)
-        pdb_run_lines_group.setLayout(pdb_run_lines_layout)
-
         # Run file Group
         run_file_group = QGroupBox(_("Run a file"))
         run_file_label = QLabel(_("You can also run a whole file at startup "
@@ -255,6 +220,66 @@ class IPythonConsoleConfigPage(PluginConfigPage):
         run_file_layout.addWidget(run_file_browser)
         run_file_group.setLayout(run_file_layout)
 
+        # ---- Debug ----
+        # Pdb run lines Group
+        pdb_run_lines_group = QGroupBox(_("Run code while debugging"))
+        pdb_run_lines_label = QLabel(_(
+            "You can run several lines of code on each "
+            "new prompt while debugging. Please "
+            "introduce each one separated by semicolons "
+            "and a space, for example:<br>"
+            "<i>import matplotlib.pyplot as plt</i>"))
+        pdb_run_lines_label.setWordWrap(True)
+        pdb_run_lines_edit = self.create_lineedit(
+            _("Lines:"), 'startup/pdb_run_lines', '', alignment=Qt.Horizontal)
+
+        pdb_run_lines_layout = QVBoxLayout()
+        pdb_run_lines_layout.addWidget(pdb_run_lines_label)
+        pdb_run_lines_layout.addWidget(pdb_run_lines_edit)
+        pdb_run_lines_group.setLayout(pdb_run_lines_layout)
+
+        # Debug Group
+        debug_group = QGroupBox(_("Debug"))
+        debug_layout = QVBoxLayout()
+
+        prevent_closing_box = newcb(
+            _("Prevent editor from closing files while debugging"),
+            'pdb_prevent_closing',
+            tip=_("This option prevents the user from closing a file while"
+                  " it is debugged."))
+        debug_layout.addWidget(prevent_closing_box)
+
+        continue_box = newcb(
+            _("Stop debugging on first line of files without breakpoints"),
+            'pdb_stop_first_line',
+            tip=_("This option lets you decide if the debugger should"
+                  " stop on the first line while debugging if no breakpoints"
+                  " are present."))
+        debug_layout.addWidget(continue_box)
+
+        libraries_box = newcb(
+            _("Ignore Python libraries while debugging"), 'pdb_ignore_lib',
+            tip=_("This option lets you decide if the debugger should "
+                  "ignore the system libraries while debugging."))
+        debug_layout.addWidget(libraries_box)
+
+        execute_events_box = newcb(
+            _("Process execute events while debugging"), 'pdb_execute_events',
+            tip=_("This option lets you decide if the debugger should "
+                  "process the 'execute events' after each prompt, such as "
+                  "matplotlib 'show' command."))
+        debug_layout.addWidget(execute_events_box)
+
+        exclamation_mark_box = newcb(
+            _("Use exclamation mark prefix for Pdb commands"),
+            'pdb_use_exclamation_mark',
+            tip=_("This option lets you decide if the Pdb commands should "
+                  "be prefixed by an exclamation mark. This helps in "
+                  "separating Pdb commands from Python code."))
+        debug_layout.addWidget(exclamation_mark_box)
+
+        debug_group.setLayout(debug_layout)
+
         # ---- Advanced settings ----
         # Enable Jedi completion
         jedi_group = QGroupBox(_("Jedi completion"))
@@ -386,19 +411,20 @@ class IPythonConsoleConfigPage(PluginConfigPage):
         windows_group.setLayout(windows_layout)
 
         # --- Tabs organization ---
-        tabs = QTabWidget()
-        tabs.addTab(self.create_tab(interface_group, comp_group,
-                                    source_code_group), _("Display"))
-        tabs.addTab(self.create_tab(pylab_group, backend_group, inline_group),
-                    _("Graphics"))
-        tabs.addTab(self.create_tab(run_lines_group, pdb_run_lines_group,
-                                    run_file_group),
-                    _("Startup"))
-        tabs.addTab(self.create_tab(jedi_group, greedy_group, autocall_group,
-                                    sympy_group, prompts_group,
-                                    windows_group),
-                    _("Advanced settings"))
+        self.tabs = QTabWidget()
+        self.tabs.addTab(self.create_tab(interface_group, comp_group,
+                                         source_code_group), _("Display"))
+        self.tabs.addTab(self.create_tab(
+            pylab_group, backend_group, inline_group), _("Graphics"))
+        self.tabs.addTab(self.create_tab(
+            run_lines_group, run_file_group), _("Startup"))
+        self.tabs.addTab(self.create_tab(
+            debug_group, pdb_run_lines_group), _("Debugger"))
+        self.tabs.addTab(self.create_tab(
+            jedi_group, greedy_group, autocall_group,
+            sympy_group, prompts_group,
+            windows_group), _("Advanced settings"))
 
         vlayout = QVBoxLayout()
-        vlayout.addWidget(tabs)
+        vlayout.addWidget(self.tabs)
         self.setLayout(vlayout)
