@@ -66,9 +66,9 @@ SPYDER_KERNELS_VERSION_MSG = _(
     '>= {0} and < {1}').format(
         SPYDER_KERNELS_MIN_VERSION, SPYDER_KERNELS_MAX_VERSION)
 SPYDER_KERNELS_CONDA = (
-    f'conda install spyder-kernels={SPYDER_KERNELS_MIN_VERSION[:-2]}')
+    f'conda install spyder&#45;kernels={SPYDER_KERNELS_MIN_VERSION[:-2]}')
 SPYDER_KERNELS_PIP = (
-    f'pip install spyder-kernels=={SPYDER_KERNELS_MIN_VERSION[:-1]}*')
+    f'pip install spyder&#45;kernels=={SPYDER_KERNELS_MIN_VERSION[:-1]}*')
 
 
 class IPythonConsoleWidgetActions:
@@ -292,16 +292,14 @@ class IPythonConsoleWidget(PluginMainWidget):
                              "required to create IPython consoles. Please "
                              "make it writable.")
 
-    def __init__(self, name=None, plugin=None, parent=None,
-                 configuration=None):
-        super().__init__(name, plugin, parent, configuration=configuration)
+    def __init__(self, name=None, plugin=None, parent=None):
+        super().__init__(name, plugin, parent)
 
         self.menu_actions = None
         self.master_clients = 0
         self.clients = []
         self.filenames = []
         self.mainwindow_close = False
-        self.projects_available = False
         self.active_project_path = None
         self.create_new_client_if_empty = True
         self.css_path = self.get_conf('css_path', section='appearance')
@@ -310,6 +308,13 @@ class IPythonConsoleWidget(PluginMainWidget):
         self.initial_conf_options = self.get_conf_options()
         self.registered_spyder_kernel_handlers = {}
 
+        # Disable infowidget if requested by the user
+        self.enable_infowidget = True
+        if plugin:
+            cli_options = plugin.get_command_line_options()
+            if cli_options.no_web_widgets:
+                self.enable_infowidget = False
+
         # Attrs for testing
         self._testing = bool(os.environ.get('IPYCONSOLE_TESTING'))
         self._test_dir = os.environ.get('IPYCONSOLE_TEST_DIR')
@@ -350,13 +355,17 @@ class IPythonConsoleWidget(PluginMainWidget):
             layout.addWidget(self.tabwidget)
 
         # Info widget
-        self.infowidget = FrameWebView(self)
-        if WEBENGINE:
-            self.infowidget.page().setBackgroundColor(QColor(MAIN_BG_COLOR))
+        if self.enable_infowidget:
+            self.infowidget = FrameWebView(self)
+            if WEBENGINE:
+                self.infowidget.page().setBackgroundColor(
+                    QColor(MAIN_BG_COLOR))
+            else:
+                self.infowidget.setStyleSheet(
+                    "background:{}".format(MAIN_BG_COLOR))
+            layout.addWidget(self.infowidget)
         else:
-            self.infowidget.setStyleSheet(
-                "background:{}".format(MAIN_BG_COLOR))
-        layout.addWidget(self.infowidget)
+            self.infowidget = None
 
         # Label to inform users how to get out of the pager
         self.pager_label = QLabel(_("Press <b>Q</b> to exit pager"), self)
@@ -384,8 +393,12 @@ class IPythonConsoleWidget(PluginMainWidget):
         # See spyder-ide/spyder#11880
         self._init_asyncio_patch()
 
+        # To cache kernel properties
         self._cached_kernel_properties = None
 
+        # Initial value for the current working directory
+        self._current_working_directory = get_home_dir()
+
     def on_close(self):
         self.mainwindow_close = True
         self.close_clients()
@@ -434,7 +447,7 @@ class IPythonConsoleWidget(PluginMainWidget):
             text=_("Connect to an existing kernel"),
             tip=_("Open a new IPython console connected to an existing "
                   "kernel"),
-            triggered=self.create_client_for_kernel,
+            triggered=self._create_client_for_kernel,
         )
         self.rename_tab_action = self.create_action(
             IPythonConsoleWidgetActions.RenameTab,
@@ -798,9 +811,15 @@ class IPythonConsoleWidget(PluginMainWidget):
     @on_conf_change(option=[
         'symbolic_math', 'hide_cmd_windows',
         'startup/run_lines', 'startup/use_run_file', 'startup/run_file',
-        'pylab', 'pylab/backend'])
-    def change_possible_restart_conf(self, option, value):
-        """Apply options that possibly require a kernel restart."""
+        'pylab', 'pylab/backend', 'pylab/autoload',
+        'pylab/inline/figure_format', 'pylab/inline/resolution',
+        'pylab/inline/width', 'pylab/inline/height',
+        'pylab/inline/bbox_inches'])
+    def change_possible_restart_and_mpl_conf(self, option, value):
+        """
+        Apply options that possibly require a kernel restart or related to
+        Matplotlib inline backend options.
+        """
         # Check that we are not triggering validations in the initial
         # notification sent when Spyder is starting or when another option
         # already required a restart and the restart dialog was shown
@@ -1061,156 +1080,16 @@ class IPythonConsoleWidget(PluginMainWidget):
         except RuntimeError:
             pass
 
-    def _create_client_for_kernel(self, connection_file, hostname, sshkey,
-                                  password):
-        # Verifying if the connection file exists
-        try:
-            cf_path = osp.dirname(connection_file)
-            cf_filename = osp.basename(connection_file)
-            # To change a possible empty string to None
-            cf_path = cf_path if cf_path else None
-            connection_file = find_connection_file(filename=cf_filename,
-                                                   path=cf_path)
-            if os.path.splitext(connection_file)[1] != ".json":
-                # There might be a file with the same id in the path.
-                connection_file = find_connection_file(
-                    filename=cf_filename + ".json", path=cf_path)
-        except (IOError, UnboundLocalError):
-            QMessageBox.critical(self, _('IPython'),
-                                 _("Unable to connect to "
-                                   "<b>%s</b>") % connection_file)
+    @Slot()
+    def _create_client_for_kernel(self):
+        """Create a client connected to an existing kernel"""
+        connect_output = KernelConnectionDialog.get_connection_parameters(self)
+        (connection_file, hostname, sshkey, password, ok) = connect_output
+        if not ok:
             return
-
-        # Getting the master id that corresponds to the client
-        # (i.e. the i in i/A)
-        master_id = None
-        given_name = None
-        is_external_kernel = True
-        known_spyder_kernel = False
-        slave_ord = ord('A') - 1
-        kernel_manager = None
-        stderr_obj = None
-        stdout_obj = None
-        fault_obj = None
-
-        for cl in self.clients:
-            if connection_file in cl.connection_file:
-                if cl.get_kernel() is not None:
-                    kernel_manager = cl.get_kernel()
-                connection_file = cl.connection_file
-                if master_id is None:
-                    master_id = cl.id_['int_id']
-                    is_external_kernel = cl.shellwidget.is_external_kernel
-                    known_spyder_kernel = cl.shellwidget.is_spyder_kernel
-                    if cl.stderr_obj:
-                        stderr_obj = cl.stderr_obj.copy()
-                    if cl.stdout_obj:
-                        stdout_obj = cl.stdout_obj.copy()
-                    if cl.fault_obj:
-                        fault_obj = cl.fault_obj.copy()
-                given_name = cl.given_name
-                new_slave_ord = ord(cl.id_['str_id'])
-                if new_slave_ord > slave_ord:
-                    slave_ord = new_slave_ord
-
-        # If we couldn't find a client with the same connection file,
-        # it means this is a new master client
-        if master_id is None:
-            self.master_clients += 1
-            master_id = str(self.master_clients)
-
-        # Set full client name
-        client_id = dict(int_id=master_id,
-                         str_id=chr(slave_ord + 1))
-
-        # Creating the client
-        show_elapsed_time = self.get_conf('show_elapsed_time')
-        reset_warning = self.get_conf('show_reset_namespace_warning')
-        ask_before_restart = self.get_conf('ask_before_restart')
-        client = ClientWidget(self,
-                              id_=client_id,
-                              given_name=given_name,
-                              history_filename=get_conf_path('history.py'),
-                              config_options=self.config_options(),
-                              additional_options=self.additional_options(),
-                              interpreter_versions=self.interpreter_versions(),
-                              connection_file=connection_file,
-                              context_menu_actions=self.context_menu_actions,
-                              time_label=self.time_label,
-                              hostname=hostname,
-                              is_external_kernel=is_external_kernel,
-                              is_spyder_kernel=known_spyder_kernel,
-                              show_elapsed_time=show_elapsed_time,
-                              reset_warning=reset_warning,
-                              ask_before_restart=ask_before_restart,
-                              css_path=self.css_path,
-                              configuration=self.CONFIGURATION,
-                              handlers=self.registered_spyder_kernel_handlers,
-                              stderr_obj=stderr_obj,
-                              stdout_obj=stdout_obj,
-                              fault_obj=fault_obj)
-
-        # Create kernel client
-        kernel_client = QtKernelClient(connection_file=connection_file)
-
-        # This is needed for issue spyder-ide/spyder#9304.
-        try:
-            kernel_client.load_connection_file()
-        except Exception as e:
-            QMessageBox.critical(self, _('Connection error'),
-                                 _("An error occurred while trying to load "
-                                   "the kernel connection file. The error "
-                                   "was:\n\n") + str(e))
-            return
-
-        if hostname is not None:
-            try:
-                connection_info = dict(
-                    ip=kernel_client.ip,
-                    shell_port=kernel_client.shell_port,
-                    iopub_port=kernel_client.iopub_port,
-                    stdin_port=kernel_client.stdin_port,
-                    hb_port=kernel_client.hb_port)
-                newports = self.tunnel_to_kernel(connection_info, hostname,
-                                                 sshkey, password)
-                (kernel_client.shell_port,
-                 kernel_client.iopub_port,
-                 kernel_client.stdin_port,
-                 kernel_client.hb_port) = newports
-                # Save parameters to connect comm later
-                kernel_client.ssh_parameters = (hostname, sshkey, password)
-            except Exception as e:
-                QMessageBox.critical(self, _('Connection error'),
-                                     _("Could not open ssh tunnel. The "
-                                       "error was:\n\n") + str(e))
-                return
-
-        # Assign kernel manager and client to shellwidget
-        kernel_client.start_channels()
-        shellwidget = client.shellwidget
-        shellwidget.set_kernel_client_and_manager(
-            kernel_client, kernel_manager)
-        shellwidget.sig_exception_occurred.connect(
-            self.sig_exception_occurred)
-
-        if not known_spyder_kernel:
-            shellwidget.sig_is_spykernel.connect(
-                self.connect_external_spyder_kernel)
-            shellwidget.check_spyder_kernel()
-
-        self.sig_shellwidget_created.emit(shellwidget)
-        kernel_client.stopped_channels.connect(
-            lambda: self.sig_shellwidget_deleted.emit(shellwidget))
-
-        # Set elapsed time, if possible
-        if not is_external_kernel:
-            self.set_client_elapsed_time(client)
-
-        # Adding a new tab for the client
-        self.add_tab(client, name=client.get_name())
-
-        # Register client
-        self.register_client(client)
+        else:
+            self.create_client_for_kernel(connection_file, hostname, sshkey,
+                                          password)
 
     # ---- Public API
     # -------------------------------------------------------------------------
@@ -1221,7 +1100,7 @@ class IPythonConsoleWidget(PluginMainWidget):
         self._font = font
         self._rich_font = rich_font
 
-        if self.infowidget:
+        if self.enable_infowidget:
             self.infowidget.set_font(rich_font)
 
         for client in self.clients:
@@ -1245,14 +1124,16 @@ class IPythonConsoleWidget(PluginMainWidget):
             client = self.tabwidget.currentWidget()
 
             # Decide what to show for each client
-            if client.info_page != client.blank_page:
+            if (client.info_page != client.blank_page and
+                    self.enable_infowidget):
                 # Show info_page if it has content
                 client.set_info_page()
                 client.shellwidget.hide()
                 client.layout.addWidget(self.infowidget)
                 self.infowidget.show()
             else:
-                self.infowidget.hide()
+                if self.enable_infowidget:
+                    self.infowidget.hide()
                 client.shellwidget.show()
 
             # Get reference for the control widget of the selected tab
@@ -1331,7 +1212,7 @@ class IPythonConsoleWidget(PluginMainWidget):
             pass
 
     def rename_client_tab(self, client, given_name):
-        """Rename client's tab."""
+        """Rename a client's tab."""
         index = self.get_client_index_from_id(id(client))
 
         if given_name is not None:
@@ -1527,14 +1408,15 @@ class IPythonConsoleWidget(PluginMainWidget):
     @Slot(bool, bool)
     @Slot(bool, str, bool)
     def create_new_client(self, give_focus=True, filename='', is_cython=False,
-                          is_pylab=False, is_sympy=False, given_name=None):
+                          is_pylab=False, is_sympy=False, given_name=None,
+                          cache=True):
         """Create a new client"""
         self.master_clients += 1
         client_id = dict(int_id=str(self.master_clients),
                          str_id='A')
         std_dir = self._test_dir if self._test_dir else None
         cf, km, kc, stderr_obj, stdout_obj = self.get_new_kernel(
-            is_cython, is_pylab, is_sympy, std_dir=std_dir)
+            is_cython, is_pylab, is_sympy, std_dir=std_dir, cache=cache)
 
         if cf is not None:
             fault_obj = StdFile(cf, '.fault', std_dir)
@@ -1562,7 +1444,6 @@ class IPythonConsoleWidget(PluginMainWidget):
                               ask_before_restart=ask_before_restart,
                               ask_before_closing=ask_before_closing,
                               css_path=self.css_path,
-                              configuration=self.CONFIGURATION,
                               handlers=self.registered_spyder_kernel_handlers,
                               stderr_obj=stderr_obj,
                               stdout_obj=stdout_obj,
@@ -1618,6 +1499,157 @@ class IPythonConsoleWidget(PluginMainWidget):
             return
         self.register_client(client, give_focus=give_focus)
 
+    def create_client_for_kernel(self, connection_file, hostname, sshkey,
+                                 password):
+        """Create a client connected to an existing kernel."""
+        # Verifying if the connection file exists
+        try:
+            cf_path = osp.dirname(connection_file)
+            cf_filename = osp.basename(connection_file)
+            # To change a possible empty string to None
+            cf_path = cf_path if cf_path else None
+            connection_file = find_connection_file(filename=cf_filename,
+                                                   path=cf_path)
+            if os.path.splitext(connection_file)[1] != ".json":
+                # There might be a file with the same id in the path.
+                connection_file = find_connection_file(
+                    filename=cf_filename + ".json", path=cf_path)
+        except (IOError, UnboundLocalError):
+            QMessageBox.critical(self, _('IPython'),
+                                 _("Unable to connect to "
+                                   "<b>%s</b>") % connection_file)
+            return
+
+        # Getting the master id that corresponds to the client
+        # (i.e. the i in i/A)
+        master_id = None
+        given_name = None
+        is_external_kernel = True
+        known_spyder_kernel = False
+        slave_ord = ord('A') - 1
+        kernel_manager = None
+        stderr_obj = None
+        stdout_obj = None
+        fault_obj = None
+
+        for cl in self.clients:
+            if connection_file in cl.connection_file:
+                if cl.get_kernel() is not None:
+                    kernel_manager = cl.get_kernel()
+                connection_file = cl.connection_file
+                if master_id is None:
+                    master_id = cl.id_['int_id']
+                    is_external_kernel = cl.shellwidget.is_external_kernel
+                    known_spyder_kernel = cl.shellwidget.is_spyder_kernel
+                    if cl.stderr_obj:
+                        stderr_obj = cl.stderr_obj.copy()
+                    if cl.stdout_obj:
+                        stdout_obj = cl.stdout_obj.copy()
+                    if cl.fault_obj:
+                        fault_obj = cl.fault_obj.copy()
+                given_name = cl.given_name
+                new_slave_ord = ord(cl.id_['str_id'])
+                if new_slave_ord > slave_ord:
+                    slave_ord = new_slave_ord
+
+        # If we couldn't find a client with the same connection file,
+        # it means this is a new master client
+        if master_id is None:
+            self.master_clients += 1
+            master_id = str(self.master_clients)
+
+        # Set full client name
+        client_id = dict(int_id=master_id,
+                         str_id=chr(slave_ord + 1))
+
+        # Creating the client
+        show_elapsed_time = self.get_conf('show_elapsed_time')
+        reset_warning = self.get_conf('show_reset_namespace_warning')
+        ask_before_restart = self.get_conf('ask_before_restart')
+        client = ClientWidget(self,
+                              id_=client_id,
+                              given_name=given_name,
+                              history_filename=get_conf_path('history.py'),
+                              config_options=self.config_options(),
+                              additional_options=self.additional_options(),
+                              interpreter_versions=self.interpreter_versions(),
+                              connection_file=connection_file,
+                              context_menu_actions=self.context_menu_actions,
+                              time_label=self.time_label,
+                              hostname=hostname,
+                              is_external_kernel=is_external_kernel,
+                              is_spyder_kernel=known_spyder_kernel,
+                              show_elapsed_time=show_elapsed_time,
+                              reset_warning=reset_warning,
+                              ask_before_restart=ask_before_restart,
+                              css_path=self.css_path,
+                              handlers=self.registered_spyder_kernel_handlers,
+                              stderr_obj=stderr_obj,
+                              stdout_obj=stdout_obj,
+                              fault_obj=fault_obj)
+
+        # Create kernel client
+        kernel_client = QtKernelClient(connection_file=connection_file)
+
+        # This is needed for issue spyder-ide/spyder#9304.
+        try:
+            kernel_client.load_connection_file()
+        except Exception as e:
+            QMessageBox.critical(self, _('Connection error'),
+                                 _("An error occurred while trying to load "
+                                   "the kernel connection file. The error "
+                                   "was:\n\n") + str(e))
+            return
+
+        if hostname is not None:
+            try:
+                connection_info = dict(
+                    ip=kernel_client.ip,
+                    shell_port=kernel_client.shell_port,
+                    iopub_port=kernel_client.iopub_port,
+                    stdin_port=kernel_client.stdin_port,
+                    hb_port=kernel_client.hb_port)
+                newports = self.tunnel_to_kernel(connection_info, hostname,
+                                                 sshkey, password)
+                (kernel_client.shell_port,
+                 kernel_client.iopub_port,
+                 kernel_client.stdin_port,
+                 kernel_client.hb_port) = newports
+                # Save parameters to connect comm later
+                kernel_client.ssh_parameters = (hostname, sshkey, password)
+            except Exception as e:
+                QMessageBox.critical(self, _('Connection error'),
+                                     _("Could not open ssh tunnel. The "
+                                       "error was:\n\n") + str(e))
+                return
+
+        # Assign kernel manager and client to shellwidget
+        kernel_client.start_channels()
+        shellwidget = client.shellwidget
+        shellwidget.set_kernel_client_and_manager(
+            kernel_client, kernel_manager)
+        shellwidget.sig_exception_occurred.connect(
+            self.sig_exception_occurred)
+
+        if not known_spyder_kernel:
+            shellwidget.sig_is_spykernel.connect(
+                self.connect_external_spyder_kernel)
+            shellwidget.check_spyder_kernel()
+
+        self.sig_shellwidget_created.emit(shellwidget)
+        kernel_client.stopped_channels.connect(
+            lambda: self.sig_shellwidget_deleted.emit(shellwidget))
+
+        # Set elapsed time, if possible
+        if not is_external_kernel:
+            self.set_client_elapsed_time(client)
+
+        # Adding a new tab for the client
+        self.add_tab(client, name=client.get_name())
+
+        # Register client
+        self.register_client(client)
+
     def create_pylab_client(self):
         """Force creation of Pylab client"""
         self.create_new_client(is_pylab=True, given_name="Pylab")
@@ -1630,19 +1662,8 @@ class IPythonConsoleWidget(PluginMainWidget):
         """Force creation of Cython client"""
         self.create_new_client(is_cython=True, given_name="Cython")
 
-    @Slot()
-    def create_client_for_kernel(self):
-        """Create a client connected to an existing kernel"""
-        connect_output = KernelConnectionDialog.get_connection_parameters(self)
-        (connection_file, hostname, sshkey, password, ok) = connect_output
-        if not ok:
-            return
-        else:
-            self._create_client_for_kernel(connection_file, hostname, sshkey,
-                                           password)
-
     def get_new_kernel(self, is_cython=False, is_pylab=False,
-                       is_sympy=False, std_dir=None):
+                       is_sympy=False, std_dir=None, cache=True):
         """Get a new kernel, and cache one for next time."""
         # Cache another kernel for next time.
         kernel_spec = self.create_kernel_spec(
@@ -1652,8 +1673,9 @@ class IPythonConsoleWidget(PluginMainWidget):
         )
 
         new_kernel = self.create_new_kernel(kernel_spec, std_dir)
-        if new_kernel[2] is None:
-            # error
+
+        if new_kernel[2] is None or not cache:
+            # error or remove/don't use cache if requested
             self.close_cached_kernel()
             return new_kernel
 
@@ -1739,8 +1761,6 @@ class IPythonConsoleWidget(PluginMainWidget):
         # This avoids a recurrent, spurious NameError when running our
         # tests in our CIs
         if not self._testing:
-            kc.started_channels.connect(
-                lambda c=client: self._shellwidget_started(c))
             kc.stopped_channels.connect(
                 lambda c=client: self._shellwidget_deleted(c))
 
@@ -1752,6 +1772,25 @@ class IPythonConsoleWidget(PluginMainWidget):
         shellwidget.sig_exception_occurred.connect(
             self.sig_exception_occurred)
 
+        # _shellwidget_started() – which emits sig_shellwidget_created() – must
+        # be called *after* set_kernel_client_and_manager() has been called.
+        # This is required so that plugins can rely on a initialized shell
+        # widget in their implementation of
+        # ShellConnectMainWidget.create_new_widget() (e.g. if they need to
+        # communicate with the kernel using the shell widget kernel client).
+        #
+        # NOTE kc.started_channels() signal must not be used to emit
+        # sig_shellwidget_created(): kc.start_channels()
+        # (QtKernelClientMixin.start_channels() from qtconsole module) emits the
+        # started_channels() signal. Slots connected to this signal are called
+        # directly from within start_channels() [1], i.e. before the shell
+        # widget’s initialization by set_kernel_client_and_manager().
+        #
+        # [1] Assuming no threads are involved, i.e. the signal-slot connection
+        # type is Qt.DirectConnection.
+        self._shellwidget_started(client)
+
+
     @Slot(str)
     def create_client_from_path(self, path):
         """Create a client with its cwd pointing to path."""
@@ -1808,31 +1847,6 @@ class IPythonConsoleWidget(PluginMainWidget):
         # To handle %edit magic petitions
         shellwidget.custom_edit_requested.connect(self.edit_file)
 
-        # Set shell cwd according to preferences
-        cwd_path = ''
-        if self.get_conf(
-                'console/use_project_or_home_directory', section='workingdir'):
-            cwd_path = get_home_dir()
-            if (self.projects_available and
-                    self.active_project_path is not None):
-                cwd_path = self.active_project_path
-        elif self.get_conf(
-                'startup/use_fixed_directory', section='workingdir'):
-            cwd_path = self.get_conf(
-                'startup/fixed_directory',
-                default=get_home_dir(),
-                section='workingdir')
-        elif self.get_conf(
-                'console/use_fixed_directory', section='workingdir'):
-            cwd_path = self.get_conf(
-                'console/fixed_directory', section='workingdir')
-
-        if osp.isdir(cwd_path) and self._plugin.main is not None:
-            shellwidget.set_cwd(cwd_path)
-            if give_focus:
-                # Syncronice cwd with explorer and cwd widget
-                shellwidget.update_cwd()
-
         # Connect client to history log
         self.sig_history_requested.emit(client.history_filename)
         client.sig_append_to_history_requested.connect(
@@ -1846,7 +1860,7 @@ class IPythonConsoleWidget(PluginMainWidget):
 
         # Connect to working directory
         shellwidget.sig_working_directory_changed.connect(
-            self.set_working_directory)
+            self.working_directory_changed)
 
         # Connect client execution state to be reflected in the interface
         client.sig_execution_state_changed.connect(self.update_actions)
@@ -1985,7 +1999,7 @@ class IPythonConsoleWidget(PluginMainWidget):
         for i in range(len(self.clients)):
             client = self.clients[-1]
             self.close_client(client=client, ask_recursive=False)
-        self.create_new_client(give_focus=False)
+        self.create_new_client(give_focus=False, cache=False)
         self.create_new_client_if_empty = True
 
     def current_client_inspect_object(self):
@@ -2084,8 +2098,7 @@ class IPythonConsoleWidget(PluginMainWidget):
         """Create a kernel spec for our own kernels"""
         return SpyderKernelSpec(is_cython=is_cython,
                                 is_pylab=is_pylab,
-                                is_sympy=is_sympy,
-                                configuration=self.CONFIGURATION)
+                                is_sympy=is_sympy)
 
     def create_kernel_manager_and_kernel_client(self, connection_file,
                                                 stderr_handle,
@@ -2359,15 +2372,27 @@ class IPythonConsoleWidget(PluginMainWidget):
             )
 
     # ---- For working directory and path management
+    def set_working_directory(self, new_dir):
+        """
+        Set current working directory when changed by the Working Directory
+        plugin.
+        """
+        self._current_working_directory = new_dir
+
+    def get_working_directory(self):
+        """Get current working directory."""
+        return self._current_working_directory
+
     def set_current_client_working_directory(self, directory):
         """Set current client working directory."""
         shellwidget = self.get_current_shellwidget()
         if shellwidget is not None:
             shellwidget.set_cwd(directory)
 
-    def set_working_directory(self, dirname):
-        """Set current working directory.
-        In the workingdirectory and explorer plugins.
+    def working_directory_changed(self, dirname):
+        """
+        Notify that the working directory was changed in the current console
+        to other plugins.
         """
         if osp.isdir(dirname):
             self.sig_current_directory_changed.emit(dirname)
@@ -2385,6 +2410,10 @@ class IPythonConsoleWidget(PluginMainWidget):
             if shell is not None:
                 shell.update_syspath(path_dict, new_path_dict)
 
+    def get_active_project_path(self):
+        """Get the active project path."""
+        return self.active_project_path
+
     def update_active_project_path(self, active_project_path):
         """
         Update the active project path attribute used to set the current
@@ -2398,7 +2427,6 @@ class IPythonConsoleWidget(PluginMainWidget):
         Returns
         -------
         None.
-
         """
         self.active_project_path = active_project_path
 
